# pelutils
Utility functions that we commonly use including flexible parser, logger and time taker.

## Parser
A combination of parsing CLI and config file arguments which allows for a powerful, easy-to-use workflow.
Useful for parametric methods such as machine learning.

## Logger
Easy to use logger which fit common needs.

## TickTock
Simple time taker inspired by Matlab Tic, Toc.

## DataStorage
Mutation of dataclass that saves/loads its fields from disk
